# -*- coding: utf-8 -*-
# This file has been autogenerated by the pywayland scanner

# Copyright 2015 Sean Vig
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from pywayland.interface import Interface


class WlDestructor(Interface):
    """Destructor object

    An interface object with a destructor request.

    And a multiline description.
    """
    name = "wl_destructor"
    version = 1


@WlDestructor.request("niiiiu", [WlDestructor, None, None, None, None, None])
def create_interface(self, x, y, width, height, format):
    """Create another interface

    Create a :class:`WlDestructor` interface object

    :param x:
    :type x: `int`
    :param y:
    :type y: `int`
    :param width:
    :type width: `int`
    :param height:
    :type height: `int`
    :param format:
    :type format: `uint`
    :returns:
        :class:`WlDestructor`
    """
    id = self._marshal_constructor(0, WlDestructor, x, y, width, height, format)
    return id


@WlDestructor.request("", [])
def destroy(self):
    """Destroy the interface

    Destroy the created interface.
    """
    self._marshal(1)
    self._destroy()


WlDestructor._gen_c()
